@@ -1,35 +1,26 @@
-import pytest
+from edalize_common import make_edalize_test
 
-def test_diamond():
+
+def test_diamond(make_edalize_test):
+    name = 'test_diamond_0'
+    tf = make_edalize_test('diamond',
+                           test_name=name,
+                           param_types=['generic', 'vlogdefine', 'vlogparam'],
+                           tool_options={
+                               'part': 'LFE5U-85F-6BG381C',
+                           })
+
+    tf.backend.configure()
+
+    tf.compare_files([name + '.tcl', name + '_run.tcl'])
+
+    tf.backend.build()
+
+    tf.compare_files(['diamondc.cmd'])
+
+
+def test_diamond_minimal(tmpdir):
     import os
-    import shutil
-    from edalize_common import compare_files, setup_backend, tests_dir
-
-    ref_dir      = os.path.join(tests_dir, __name__)
-    paramtypes   = ['generic', 'vlogdefine', 'vlogparam']
-    tool         = 'diamond'
-    name         = 'test_{}_0'.format(tool)
-    tool_options = {
-        'part' : 'LFE5U-85F-6BG381C',
-    }
-
-    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options)
-    backend.configure()
-
-    compare_files(ref_dir, work_root, [
-        name+'.tcl',
-        name+'_run.tcl',
-    ])
-
-    backend.build()
-    compare_files(ref_dir, work_root, [
-        'diamondc.cmd',
-    ])
-
-def test_diamond_minimal():
-    import os
-    import shutil
-    import tempfile
 
     from edalize import get_edatool
 
@@ -42,7 +33,7 @@ def test_diamond_minimal():
         'part' : 'LFE5U-85F-6BG381C',
     }
     name = 'test_{}_minimal_0'.format(tool)
-    work_root = tempfile.mkdtemp(prefix=tool+'_')
+    work_root = str(tmpdir)
 
     edam = {'name'         : name,
             'tool_options' : {tool : tool_options}
