@@ -1,60 +1,37 @@
-import pytest
+from edalize_common import make_edalize_test
 
 
-def test_vcs_tool_options():
-    import os
-    import shutil
-    from edalize_common import compare_files, setup_backend, tests_dir
+def run_vcs_test(tf):
+    tf.backend.configure()
 
-    ref_dir = os.path.join(tests_dir, __name__, 'tool_options')
-    paramtypes = ['plusarg', 'vlogdefine', 'vlogparam']
-    name = 'test_vcs_tool_options_0'
-    tool = 'vcs'
+    tf.compare_files(['Makefile', tf.test_name + '.scr'])
+
+    tf.backend.build()
+    tf.compare_files(['vcs.cmd'])
+
+    tf.backend.run()
+    tf.compare_files(['run.cmd'])
+
+
+def test_vcs_tool_options(make_edalize_test):
     tool_options = {
         'vcs_options'  : [ '-debug_access+pp', '-debug_access+all' ],
         'run_options'  : [ '-licqueue' ],
     }
-
-    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
-    backend.configure()
-
-    compare_files(ref_dir, work_root, ['Makefile', name + '.scr' ])
-
-    backend.build()
-    compare_files(ref_dir, work_root, ['vcs.cmd'])
-
-    backend.run()
-
-    compare_files(ref_dir, work_root, ['run.cmd'])
+    tf = make_edalize_test('vcs',
+                           test_name='test_vcs_tool_options_0',
+                           ref_dir='tool_options',
+                           tool_options=tool_options)
+    run_vcs_test(tf)
 
 
-def test_vcs_no_tool_options():
+def test_vcs_no_tool_options(make_edalize_test):
+    tf = make_edalize_test('vcs', ref_dir='no_tool_options')
+    run_vcs_test(tf)
+
+
+def test_vcs_minimal(tmpdir):
     import os
-    import shutil
-    from edalize_common import compare_files, setup_backend, tests_dir
-
-    ref_dir      = os.path.join(tests_dir, __name__, 'no_tool_options')
-    paramtypes   = ['plusarg', 'vlogdefine', 'vlogparam']
-    name         = 'test_vcs_0'
-    tool         = 'vcs'
-    tool_options = {}
-
-    (backend, work_root) = setup_backend(paramtypes, name, tool, tool_options, use_vpi=False)
-    backend.configure()
-
-    compare_files(ref_dir, work_root, ['Makefile', name + '.scr' ])
-
-    backend.build()
-    compare_files(ref_dir, work_root, ['vcs.cmd'])
-
-    backend.run()
-
-    compare_files(ref_dir, work_root, ['run.cmd'])
-
-def test_vcs_minimal():
-    import os
-    import shutil
-    import tempfile
 
     from edalize import get_edatool
 
@@ -64,7 +41,7 @@ def test_vcs_minimal():
     os.environ['PATH'] = os.path.join(tests_dir, 'mock_commands')+':'+os.environ['PATH']
     tool = 'vcs'
     name = 'test_'+tool+'_minimal_0'
-    work_root = tempfile.mkdtemp(prefix=tool+'_')
+    work_root = str(tmpdir)
 
     edam = {'name'         : name,
                'toplevel' : 'top'}
@@ -80,3 +57,4 @@ def test_vcs_minimal():
     backend.run()
 
     compare_files(ref_dir, work_root, ['run.cmd'])
+
